DecodedSampleFormat enum

Identifies the scalar representation of decoded channel samples.

Inheritance
Available extensions

Values

uint8 → const DecodedSampleFormat

Unsigned normalized eight-bit integers.

const DecodedSampleFormat(bitsPerChannel: 8, bytesPerChannel: 1)
uint16 → const DecodedSampleFormat

Unsigned normalized sixteen-bit integers.

const DecodedSampleFormat(bitsPerChannel: 16, bytesPerChannel: 2)
float32 → const DecodedSampleFormat

IEEE-754 single-precision values, normally normalized but HDR-capable.

const DecodedSampleFormat(bitsPerChannel: 32, bytesPerChannel: 4)

Properties

bitsPerChannel → int
Significant storage depth of one channel.
final
bytesPerChannel → int
Bytes occupied by one channel.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DecodedSampleFormat>
A constant List of the values in this enum, in order of their declaration.