QoiEncoder class final

Encodes RGBA pixels using the Quite OK Image specification.

Inheritance

Constructors

QoiEncoder({QoiEncodeOptions defaultOptions = const QoiEncodeOptions()})
Creates a QOI encoder.
const

Properties

defaultEncodeOptions → QoiEncodeOptions
The default encode options.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<Image> stream) → Stream<Uint8List>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List
Converts input and returns the result of the conversion.
inherited
encode(Image input, {QoiEncodeOptions? encodeOptions}) → Uint8List
Encodes input to raster bytes.
inherited
encodeWithOptions(Image image, QoiEncodeOptions options) → Uint8List
Encodes image losslessly in the sRGB color space.
override
fuse<TT>(Converter<Uint8List, TT> other) → Converter<Image, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Uint8List> sink) → Sink<Image>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited